==> telepathy-qt4-0.9.6.1-2-armv7h.pkg.tar.xz: usr/lib/cmake/TelepathyQt4/TelepathyQt4Targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "telepathy-qt4" for configuration "Release"
set_property(TARGET telepathy-qt4 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(telepathy-qt4 PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "/usr/lib/libQtCore.so;/usr/lib/libQtDBus.so;/usr/lib/libQtNetwork.so;/usr/lib/libQtXml.so"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libtelepathy-qt4.so.2.0.9.6.1"
  IMPORTED_SONAME_RELEASE "libtelepathy-qt4.so.2"
  )

list(APPEND _IMPORT_CHECK_TARGETS telepathy-qt4 )
list(APPEND _IMPORT_CHECK_FILES_FOR_telepathy-qt4 "${_IMPORT_PREFIX}/lib/libtelepathy-qt4.so.2.0.9.6.1" )

# Import target "telepathy-qt4-farstream" for configuration "Release"
set_property(TARGET telepathy-qt4-farstream APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(telepathy-qt4-farstream PROPERTIES
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "/usr/lib/libQtDBus.so;/usr/lib/libQtCore.so;gobject-2.0;glib-2.0;/usr/lib/libtelepathy-farstream.so;/usr/lib/libtelepathy-glib.so;telepathy-qt4"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libtelepathy-qt4-farstream.so.2.0.9.6.1"
  IMPORTED_SONAME_RELEASE "libtelepathy-qt4-farstream.so.2"
  )

list(APPEND _IMPORT_CHECK_TARGETS telepathy-qt4-farstream )
list(APPEND _IMPORT_CHECK_FILES_FOR_telepathy-qt4-farstream "${_IMPORT_PREFIX}/lib/libtelepathy-qt4-farstream.so.2.0.9.6.1" )

# Import target "telepathy-qt4-service" for configuration "Release"
set_property(TARGET telepathy-qt4-service APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(telepathy-qt4-service PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LINK_INTERFACE_LIBRARIES_RELEASE "/usr/lib/libQtDBus.so;/usr/lib/libQtCore.so"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libtelepathy-qt4-service.a"
  )

list(APPEND _IMPORT_CHECK_TARGETS telepathy-qt4-service )
list(APPEND _IMPORT_CHECK_FILES_FOR_telepathy-qt4-service "${_IMPORT_PREFIX}/lib/libtelepathy-qt4-service.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> telepathy-qt4-0.9.7-1-armv7h.pkg.tar.xz: usr/lib/cmake/TelepathyQt4/TelepathyQt4Targets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "Release".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "telepathy-qt4" for configuration "Release"
set_property(TARGET telepathy-qt4 APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(telepathy-qt4 PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libtelepathy-qt4.so.2.0.9.7"
  IMPORTED_SONAME_RELEASE "libtelepathy-qt4.so.2"
  )

list(APPEND _IMPORT_CHECK_TARGETS telepathy-qt4 )
list(APPEND _IMPORT_CHECK_FILES_FOR_telepathy-qt4 "${_IMPORT_PREFIX}/lib/libtelepathy-qt4.so.2.0.9.7" )

# Import target "telepathy-qt4-farstream" for configuration "Release"
set_property(TARGET telepathy-qt4-farstream APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(telepathy-qt4-farstream PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libtelepathy-qt4-farstream.so.2.0.9.7"
  IMPORTED_SONAME_RELEASE "libtelepathy-qt4-farstream.so.2"
  )

list(APPEND _IMPORT_CHECK_TARGETS telepathy-qt4-farstream )
list(APPEND _IMPORT_CHECK_FILES_FOR_telepathy-qt4-farstream "${_IMPORT_PREFIX}/lib/libtelepathy-qt4-farstream.so.2.0.9.7" )

# Import target "telepathy-qt4-service" for configuration "Release"
set_property(TARGET telepathy-qt4-service APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(telepathy-qt4-service PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libtelepathy-qt4-service.so.2.0.9.7"
  IMPORTED_SONAME_RELEASE "libtelepathy-qt4-service.so.0"
  )

list(APPEND _IMPORT_CHECK_TARGETS telepathy-qt4-service )
list(APPEND _IMPORT_CHECK_FILES_FOR_telepathy-qt4-service "${_IMPORT_PREFIX}/lib/libtelepathy-qt4-service.so.2.0.9.7" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
